pub fn strip_attributes(input: TokenStream) -> TokenStreamExpand description
Strip all logos attributes from the given struct, allowing it to be used in code without logos-derive present.
pub fn strip_attributes(input: TokenStream) -> TokenStreamStrip all logos attributes from the given struct, allowing it to be used in code without logos-derive present.